/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.anweisung;

import java.util.ArrayList;
import java.util.List;

import de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck;

/**
 * die abstrakte Implementierung einer einfachen Anweisung.<br>
 * Einfache Anweisungen innerhalb eines Uda-Skripts sind alle Anweisungen, die
 * nur einen Ausdruck auswerten:
 * <ul>
 * <li>Ausgabeanweisung, zur Ausgabe des Ergebnisses eines übergebenen Ausdrucks
 * </li>
 * <li>Benutzeanweisung, zur Einbindung eines per Name (der einzig mögliche
 * Ausdruck) übergebenen Skripts</li>
 * <li>Fehlerprüfungsanweisung, zur Auswertung eines einzelnen Ausdrucks und der
 * entsprechenden Behandlung eines aufgetretenen Fehlers</li>
 * <li>Rückgabeanweisung, liefert das Ergebnis eines Ausdrucks und beendet den
 * Anweisungsblock, in dem die Anweisung ausgeführt wurde</li>
 * <li>Zuweisungsanweisung, setzt eine Variable bzw. ein Element einer Struktur
 * oder eines Containers auf den Wert, den die Auswertung des Ausdrucks ergeben
 * hat</li>
 * </ul>
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public abstract class AbstractEinfacheAnweisung extends AbstractAnweisung {

	/**
	 * der Ausdruck der von der Anweisung ausgewertet wird.
	 */
	private final Ausdruck ausdruck;

	/**
	 * Konstruktor.
	 *
	 * @param zeile
	 *            die Nummer der Zeile innerhalb des Skript-Quelltextes
	 * @param skriptname
	 *            der Name des Skripts aus dem die Anweisung stammt
	 * @param ausdruck
	 *            der auszuwertende Ausdruck
	 */
	public AbstractEinfacheAnweisung(final int zeile, final String skriptname, final Ausdruck ausdruck) {
		super(zeile, skriptname);
		this.ausdruck = ausdruck;
	}

	/**
	 * liefert den Ausdruck, der von der Anweisung auszuwerten ist.
	 *
	 * @return der Ausdruck
	 */
	Ausdruck getAusdruck() {
		return ausdruck;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck#getNachfolger()
	 */
	@Override
	public List<Ausdruck> getNachfolger() {
		final List<Ausdruck> liste = new ArrayList<>();
		liste.add(ausdruck);
		return liste;
	}
}
