/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.anweisung;

import de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck;

/**
 * Schnittstelle zur Definition einer Anweisung innerhalb eines Uda-Skripts.<br>
 * Eine Anweisung ist selbst ein Ausdruck und wird vom Interpreter zur Laufzeit
 * ausgewertet. Eine Anweisung hat aber gegen&uuml;ber allen anderen
 * Ausdr&uuml;cken in Uda die Besonderheit, das nur diese Ausdr&uuml;cke vom
 * Interpreter selbst ausgef&uuml;hrt werden. Alle anderen Ausdr&uuml;cke werden
 * lediglich zur Bildung komplexerer Ausdr&uuml;cke und am Ende zur Bildung von
 * Anweisungen verwendet. Anweisungen können auch nicht ineinander verschachtelt
 * werden. Komplexere Anweisungen können lediglich selbst einen oder mehrere
 * Anweisungsblöcke enthalten, die "innerhalb" der Anweisung ausgef&uuml;hrt
 * werden. Anweisungen bilden damit auch die einzige Schnittstelle zur
 * Auswertung von Fehler, die bei der Auswertung von Ausdr&uuml;cken aufgetreten
 * sind.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public interface Anweisung extends Ausdruck {
	/**
	 * liefert die Nummer der Zeile, in der die Anweisung innerhalb des
	 * Skript-Quelltextes beschrieben ist.
	 *
	 * @return die Nummer der Zeile
	 */
	int getZeile();

	/**
	 * liefert den Namen des Sktipts, in dem die Anweisung definiert ist.
	 *
	 * @return den Name des Skripts
	 */
	String getSkript();
}
