/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.anweisung;

import de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck;

/**
 * die Repräsentation einer Fehlerprüfungsanweisung.<br>
 * Fehlerprüfungsanweisungen in Uda werten einen Ausdruck aus und behandlen das
 * Ergebnis nach verschiedenen Methoden:
 * <ul>
 * <li>ohne fehlerprüfung: wenn der Ausdruck einen Fehler liefert, wird dieser
 * ignoriert und das Skript mit der nachfolgenden Anweisung fortgesetzt.</li>
 * <li>mit fehlerausgabe: wenn der Ausdruck einen Fehler liefert, wird dieser
 * ausgegeben und ansonsten ignoriert, d.h. das Skript wird mit der
 * nachfolgenden Anweisung fortgesetzt.</li>
 * <li>mit fehlerrückgabe: wenn der Ausdruck einen Fehler liefert, wird dieser
 * zurückgegeben und der Anweisungsblock, in dem die Anweisung ausgeführt wurde
 * beendet.</li>
 * </ul>
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public abstract class FehlerPruefungsAnweisung extends AbstractEinfacheAnweisung {

	/**
	 * Konstruktor.
	 *
	 * @param zeile
	 *            die Zeile des Quelltextes, in der die Anweisung definiert
	 *            wurde.
	 * @param skriptname
	 *            der Name des Skripts
	 * @param ausdruck
	 *            der Ausdruck der ausgewertet werden soll
	 */
	public FehlerPruefungsAnweisung(final int zeile, final String skriptname, final Ausdruck ausdruck) {
		super(zeile, skriptname, ausdruck);
	}
}
