/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.dav;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.ibv.uda.interpreter.daten.container.Container;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.ContainerZugriffsFehler;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.UdaFehlerSubtyp;
import de.bsvrz.sys.funclib.bitctrl.interpreter.logik.LogischerWert;

/**
 * Repräsentation eines Feldes innerhalb eines DAF-Datensatzes.
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class DavDatenFeld extends DavDaten implements Container {

	/**
	 * Konstruktor.
	 *
	 * @param verbindung
	 *            due verwendete Datenverteilerverbindung
	 * @param objekt
	 *            der zu Grunde liegende Datensatz
	 */
	public DavDatenFeld(final ClientDavInterface verbindung, final Data objekt) {
		super(verbindung, objekt.asArray());
	}

	/**
	 * {@inheritDoc}.<br>
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.container.Container#getContainerElement(int)
	 */
	@Override
	public Object getContainerElement(final int index) {
		Object result = null;

		final int arrayLaenge = getObjekt().getLength();
		int usedIndex = index;

		if ((index == 0) || ((arrayLaenge + 1 + index) <= 0)) {
			result = new ContainerZugriffsFehler(UdaFehlerSubtyp.INDEX,
					"Feldzugriff mit Index " + index + " nicht erlaubt");
		} else {
			if (index < 0) {
				usedIndex = arrayLaenge + 1 + index;
			}

			if (usedIndex > arrayLaenge) {
				getObjekt().setLength(usedIndex);
			}

			final Data data = getObjekt().getItem(usedIndex - 1);
			if (data.isArray()) {
				result = new DavDatenFeld(getVerbindung(), data);
			} else {
				result = new DavDatenObjekt(getVerbindung(), data);
			}

		}
		return result;
	}

	/**
	 * {@inheritDoc}.<br>
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.dav.DavDaten#getObjekt()
	 */
	@Override
	public Data.Array getObjekt() {
		return (Data.Array) super.getObjekt();
	}

	/**
	 * {@inheritDoc}.<br>
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.ausdruck.Struktur#getStrukturElement(java.lang.String)
	 */
	@Override
	public Object getStrukturElement(final String name) {
		// Zugriff über Strukturelemente nicht definiert
		return null;
	}

	/**
	 * {@inheritDoc}.<br>
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.container.Container#setContainerElement(int,
	 *      java.lang.Object)
	 */
	@Override
	public void setContainerElement(final int index, final Object daten) {
		if (index > getObjekt().getLength()) {
			getObjekt().setLength(index);
		}

		final Object datenObjekt = getContainerElement(index);
		if (datenObjekt instanceof DavDatenObjekt) {
			final Data data = ((DavDatenObjekt) datenObjekt).getObjekt();
			if ((daten instanceof Double) || (daten instanceof Float)) {
				data.asUnscaledValue().set(((Number) daten).doubleValue());
			} else if (daten instanceof Number) {
				data.asUnscaledValue().set(((Number) daten).longValue());
			} else if (daten instanceof LogischerWert) {
				final boolean wert = ((LogischerWert) daten).get();
				if (wert) {
					data.asUnscaledValue().set(1);
				} else {
					data.asUnscaledValue().set(0);
				}
			} else if (daten instanceof Boolean) {
				final boolean wert = (Boolean) daten;
				if (wert) {
					data.asUnscaledValue().set(1);
				} else {
					data.asUnscaledValue().set(0);
				}
			} else if (daten instanceof SystemObjectObjekt) {
				data.asReferenceValue().setSystemObject(((SystemObjectObjekt) daten).getObjekt());
			} else {
				data.asTextValue().setText(daten.toString());
			}
		}
	}

	/**
	 * {@inheritDoc}.<br>
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.ausdruck.Struktur#setStrukturElement(java.lang.String,
	 *      java.lang.Object)
	 */
	@Override
	public void setStrukturElement(final String name, final Object daten) {
		// Zugriff über Strukturelemente nicht definiert
	}

}
