/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.fehler;

import de.bsvrz.ibv.uda.interpreter.Kopierbar;

/**
 * Die Klasse beschreibt Fehler bei falschen Containerzugriffen und fehlerhaften
 * Selektionen.
 * <ol>
 * <li>Containerzugriff mit ungültigem Index</li>
 * <li>Containerselektion ohne Ergebnis</li>
 * </ol>
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class ContainerZugriffsFehler extends UdaFehler {

	/**
	 * Versions-ID.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * Konstruktor, der ein neues Fehlerobjekt aus Basis des übergebenen
	 * Fehlerobjekts erstellt.
	 *
	 * @param fehler
	 *            der ursprüngliche Fehler
	 */
	public ContainerZugriffsFehler(final ContainerZugriffsFehler fehler) {
		super(fehler);
	}

	/**
	 * Standardkonstruktor.
	 *
	 * @param subtyp
	 *            der Subtyp des Fehlers
	 */
	public ContainerZugriffsFehler(final UdaFehlerSubtyp subtyp) {
		super(subtyp);
	}

	/**
	 * Konstruktor mit Angabe des Meldungstextes.
	 *
	 * @param subtyp
	 *            der Subtyp des Fehlers
	 * @param meldung
	 *            der Meldungstext
	 */
	public ContainerZugriffsFehler(final UdaFehlerSubtyp subtyp, final String meldung) {
		super(subtyp, meldung);
	}

	/**
	 * Konstruktor mit Angabe des Meldungstextes und des Vorgängerfehlers.
	 *
	 * @param subtyp
	 *            der Subtyp des Fehlers
	 * @param text
	 *            der Meldungstext
	 * @param vorgaenger
	 *            der Vorgängerfehler
	 */
	public ContainerZugriffsFehler(final UdaFehlerSubtyp subtyp, final String text, final UdaFehler vorgaenger) {
		super(subtyp, text, vorgaenger);
	}

	/**
	 * {@inheritDoc}.<br>
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.Kopierbar#erzeugeKopie()
	 */
	@Override
	public Kopierbar erzeugeKopie() {
		return new ContainerZugriffsFehler(this);
	}
}
