/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.hysterese;

import de.bsvrz.ibv.uda.interpreter.daten.container.Feld;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.ArgumentFehler;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.UdaFehlerSubtyp;

/**
 * Die Klasse erweitert die allgemeine Datenstruktur Feld, um beim schreibenden
 * Zugriff über die Container-Schnittstelle sicherzustellen, dass nur
 * Hysteresestufen-Objekte gespeichert werden können.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class HystereseStufenFeld extends Feld {

	/**
	 * Standardkonstruktor.
	 */
	HystereseStufenFeld() {
		super();
	}

	/**
	 * Implementierung der entsprechenden Funktion der Schnittstelle
	 * <i>Container</i>.<br>
	 * Es können nur Objekte vom Typ <i>HystereseStufe</i> in das Feld
	 * aufgenommen werden. {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.container.Feld#setContainerElement(int,
	 *      java.lang.Object)
	 */
	@Override
	public void setContainerElement(final int index, final Object stufe) {
		if (!(stufe instanceof HystereseStufe)) {
			throw new ArgumentFehler(UdaFehlerSubtyp.ARGUMENTE, "In eine Hysterese kann kein Objekt vom Typ "
					+ stufe.getClass().getSimpleName() + " eingetragen werden");
		}
		super.setContainerElement(index, stufe);
	}
}
