/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.konstante;

import java.util.List;

import de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Literal;
import de.bsvrz.sys.funclib.bitctrl.interpreter.logik.LogischerWert;

/**
 * Die Repräsentation eines Literals für einen boolschen Wert innerhalb des
 * Uda-Interpreterbaumes.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class BooleanLiteral implements Literal {

	/**
	 * der Wert des Literals.
	 */
	private LogischerWert logischerWert = LogischerWert.FALSCH;

	/**
	 * Der Konstruktor erzeugt eine Instanz des Literals. Der logische Wert wird
	 * auf den ï¿½bergebenen boolschen Wert festgelegt.
	 *
	 * @param wert
	 *            der Wert
	 */
	public BooleanLiteral(final boolean wert) {
		this.logischerWert = LogischerWert.of(wert);
	}

	/**
	 * Implementiert die Funktion der Schnittstelle <i>Ausdruck</i>. Die
	 * Auswertung des Literals liefert in jedem Fall eine Instanz der Klasse
	 * <i>LogischerWert</i> zurück.
	 *
	 * @param kontext
	 *            der Kontext, in dem der Ausdruck ausgewertet wird
	 * @return einen logischen Wert
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck#interpret(de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext)
	 */
	@Override
	public final LogischerWert interpret(final Kontext kontext) {
		return logischerWert;
	}

}
