/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.ausdruck;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import de.bsvrz.ibv.uda.interpreter.daten.container.Liste;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext;

/**
 * ein Ausdruck zum Abbildung eines Listeninitialisieres innerhalb eines
 * Uda-Skripts.<br>
 * Ein Listeninitialisierer wird in Uda durch eine kommagetrennte Liste von
 * Ausdrücken, die in geschweifte Klammern eingeschlossen sind dargestellt.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class ListenInitialisiererSymbol implements Ausdruck {
	/**
	 * die Liste der Ausdrücke, die die initialien Elemente der zu erstellenden
	 * Liste beschreiben.
	 */
	private final Collection<Ausdruck> elemente = new ArrayList<>();

	/**
	 * Konstruktor.<br>
	 *
	 * @param elemente
	 *            ein Ausdruck, der die Elemente zur Initialisierung einer Liste
	 *            beschreibt
	 */
	public ListenInitialisiererSymbol(final Collection<Ausdruck> elemente) {
		this.elemente.addAll(elemente);
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck#interpret(de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext)
	 */
	@Override
	public final Object interpret(final Kontext kontext) {
		final Liste result = new Liste();
		for (final Ausdruck ausdruck : elemente) {
			result.einfuegen(0, ausdruck.interpret(kontext));
		}
		return result;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck#getNachfolger()
	 */
	@Override
	public List<Ausdruck> getNachfolger() {
		List<Ausdruck> liste = null;
		if (elemente.size() > 0) {
			liste = new ArrayList<>(elemente);
		}
		return liste;
	}
}
