/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten;

import java.util.List;

import de.bsvrz.ibv.uda.interpreter.AbstractUdaHandler;
import de.bsvrz.sys.funclib.bitctrl.interpreter.HandlerValidation;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Operator;
import de.bsvrz.sys.funclib.bitctrl.interpreter.logik.LogischerWert;

/**
 * der Handler für die Ausführung von Zeichenkettenbezogenen Operationen.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class ZeichenkettenHandler extends AbstractUdaHandler {

	/**
	 * {@inheritDoc}.<br>
	 *
	 * @return die Liste der verfügbaren Operatoren
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Handler#getHandledOperators()
	 */
	@Override
	public Operator[] getHandledOperators() {
		return ZeichenkettenOperatoren.OPERATOREN;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Handler#validiereHandler(de.bsvrz.sys.funclib.bitctrl.interpreter.Operator,
	 *      java.util.List)
	 */
	@Override
	public HandlerValidation validiereHandler(final Operator operator, final List<?> operanden) {
		final boolean anzahlOk = operanden.size() == 2;
		boolean typOk = false;

		if (ZeichenkettenOperatoren.STRING_KONKATENATION.equals(operator)) {
			typOk = true;
		} else if (ZeichenkettenOperatoren.STRING_GLEICH.equals(operator)) {
			typOk = true;
		} else if (ZeichenkettenOperatoren.STRING_UNGLEICH.equals(operator)) {
			typOk = true;
		}
		return new HandlerValidation(anzahlOk, typOk);
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Handler#perform(de.bsvrz.sys.funclib.bitctrl.interpreter.Operator,
	 *      java.util.List)
	 */
	@Override
	public Object perform(final Operator operator, final List<?> operanden) {
		erzeugeHandlerFehler(operator, operanden);
		if (ZeichenkettenOperatoren.STRING_KONKATENATION.equals(operator)) {
			final StringBuffer buffer = new StringBuffer();
			buffer.append(operanden.get(0).toString());
			buffer.append(operanden.get(1).toString());
			return buffer.toString();
		} else if (ZeichenkettenOperatoren.STRING_GLEICH.equals(operator)) {
			return LogischerWert.of(operanden.get(0).toString().equals(operanden.get(1).toString()));
		} else if (ZeichenkettenOperatoren.STRING_UNGLEICH.equals(operator)) {
			return LogischerWert.of(!operanden.get(0).toString().equals(operanden.get(1).toString()));
		}
		return null;
	}

}
