/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.uda.data;

import java.util.HashMap;
import java.util.Map;

import de.bsvrz.sys.funclib.bitctrl.daf.AbstractDavZustand;

/**
 * der Zustand eines Skriptlaufs.<br>
 * Der zustand des Skriptlaufs beschreibt letztendlich den Ausführungszustand
 * des mit ihm verbundenen Skripts. Da dieser Zustand jedoch an den Skriptlauf
 * gebunden ist, kann ein Skript mit verschiedenen Ausführungsumgebungen auch
 * mehrfach aktiv sein.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public final class SkriptLaufStatus extends AbstractDavZustand {
	/**
	 * Versions-ID für die Serialisierung des Objekts.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * die Menge aller definierten Zustände.
	 */
	private static final Map<Integer, SkriptLaufStatus> ZUSTAENDE = new HashMap<>();

	/**
	 * der Skriptlauf ist aktiv, d.h. das verbundene Skript wird ausgeführt.
	 */
	public static final SkriptLaufStatus AKTIV = new SkriptLaufStatus(1, "aktiv");

	/**
	 * der Skriptlauf ist aktiv, aber das verbundene Skript ist im Moment
	 * angehalten.
	 */
	public static final SkriptLaufStatus ANGEHALTEN = new SkriptLaufStatus(2, "angehalten");

	/**
	 * der Skriptlauf ist nicht aktiv, d.h. das verbundene Skript wird im Moment
	 * nicht ausgeführt.
	 */
	public static final SkriptLaufStatus PASSIV = new SkriptLaufStatus(3, "passiv");

	/**
	 * der Skriptlauf war aktiv und ist inzwischen beendet worden.<br>
	 * Der Zustand ist erforderlich, um einmalig sofort ausgeführte Skripte
	 * nicht sofort wieder zur Ausführung zu bringen, wenn sie in den Status
	 * PASSIV übergehen würden.
	 */
	public static final SkriptLaufStatus BEENDET = new SkriptLaufStatus(4, "beendet");

	/**
	 * Konstruktor.<br>
	 * Die Funktion erzeugt ein Zustandsobjekt mit dem übergebenen Code und dem
	 * Text.
	 *
	 * @param code
	 *            der Code
	 * @param name
	 *            der Name
	 */
	private SkriptLaufStatus(final int code, final String name) {
		super(code, name);
		SkriptLaufStatus.ZUSTAENDE.put(code, this);
	}

	/**
	 * liefert die Zustandsdefinition für den übergebenen Code.
	 *
	 * @param searchedCode
	 *            der Code
	 * @return der Zustand
	 */
	public static SkriptLaufStatus getZustand(final int searchedCode) {
		return SkriptLaufStatus.ZUSTAENDE.get(searchedCode);
	}
}
