/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.fuzzy;

import de.bsvrz.iav.fuzzylib.fuzzylib.FuzzySet;
import de.bsvrz.ibv.uda.interpreter.Kopierbar;
import de.bsvrz.ibv.uda.interpreter.ausdruck.Struktur;
import de.bsvrz.sys.funclib.bitctrl.interpreter.InterpreterException;

/**
 * Repräsentiert einen linguistsichen Term innerhalb eines UdaInterpreter.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class UdaLinguistischerTerm implements Struktur, Kopierbar {

	/**
	 * der Name des Terms.
	 */
	private final String termName;

	/**
	 * die Beschreibung des Terms.
	 */
	private final String beschreibung;

	private FuzzySet fuzzySet;

	/**
	 * Konstruktor.<br>
	 *
	 * @param name
	 *            der Name des Terms
	 * @param t2
	 *            die untere Trapezecke mit der Zugehörigkeit "1"
	 * @param t3
	 *            die oberere Trapezecke mit der Zugehörigkeit "1"
	 * @param beschreibung
	 *            beschreibender Text
	 */
	public UdaLinguistischerTerm(final String name, final double t2, final double t3, final String beschreibung) {
		fuzzySet = FuzzySet.trapezMitGleitendenUebergaengen(name, t2, t3);
		this.termName = name;
		this.beschreibung = beschreibung;
	}

	public FuzzySet getFuzzySet() {
		return fuzzySet;
	}

	/**
	 * {@inheritDoc}.<br>
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.Kopierbar#erzeugeKopie()
	 */
	@Override
	public UdaLinguistischerTerm erzeugeKopie() {
		return new UdaLinguistischerTerm(termName, fuzzySet.getT2(), fuzzySet.getT3(), beschreibung);
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.ausdruck.Struktur#getStrukturElement(java.lang.String)
	 * @see #setStrukturElement(String, Object)
	 */
	@Override
	public Object getStrukturElement(final String name) {
		Object result = null;
		if ("bezeichner".equals(name)) {
			result = fuzzySet.getName();
		} else if ("untereGrenze".equals(name)) {
			result = fuzzySet.getT2();
		} else if ("obereGrenze".equals(name)) {
			result = fuzzySet.getT3();
		} else if ("name".equals(name)) {
			result = termName;
		} else if ("beschreibung".equals(name)) {
			result = beschreibung;
		}
		return result;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.ausdruck.Struktur#setStrukturElement(java.lang.String,
	 *      java.lang.Object)
	 * @see #getStrukturElement(String)
	 */
	@Override
	public void setStrukturElement(final String name, final Object daten) {
		throw new InterpreterException("Ein Element eines linguistischen Terms kann nicht direkt gesetzt werden");
	}

	@Override
	public String toString() {
		return fuzzySet.toString();
	}

}
